<?php


/**
 * This file contains various string utility functions.
 **/




 /**
 * @brief     Add a string to a filename before its extension
 * @example e AddPreExtension( "testing.txt", "_this" ) will return "testing_this.txt"
 * @example f AddPreExtension( "testing", "_this" ) will return "testing_this"
 * @example g AddPreExtension( "can.we.test.txt", "_this" ) will return "can.we.test_this.txt"
 **/

function AddPreExtension( $str, $pre_ext )
{
  $result = $str . $pre_ext;

  if( strpos( $str, '.' ) !== false )
  {
    $last_dot = strrpos( $str, '.' );
    $result = substr( $str, 0, $last_dot - 1);
    $ext = substr( $str, $last_dot );

    $result .= $pre_ext;
    $result .= $ext;
  }

  return $result;
}


/**
  * remove extra whitespace, if we have more than one consecutive delimiter
  * character, then reduce it to 1.
  *
  *  note we are not in a run of delim characters
  *  for each character in the line
  *    if this is a delim character
  *      if we are not in a run
  *        note that we are now in a run
  *        put the character in the output line
  *    otherwise
  *      put the character in the output line
  *      note that we are no longer in a run
  **/
function eatwhite( $line, $delim = ' ' )
{
  $out = '';
  $run = false;
  for( $i = 0; $i < strlen($line); $i ++ )
  {
    if( $line[$i] == $delim )
    {
      if( !$run )
      {
	$run = true;
	$out .= $delim;
      }
    }
    else
    {
      $run = false;
      $out .= $line[$i];
    }
  }
  return $out;
}

/**
  * Get the nth word from a line of text, words are delimited by delim
  * default is space.
  *
  *  set the position of the current word to 0
  *  count from zero to n-1
  *    set the position of the current word to the next delimiter + 1
  *  if there are no more delimiters after the current word
  *    return from the current word to the end of string
  *  otherwise
  *    return from the current word to the next delimiter - 1
  **/

function strword( $line, $n, $delim = ' ' )
{
  $current = 0;
  for( $i = 0; $i < $n; $i ++ )
    $current = strpos( $line, $delim, $current ) + 1;

  $next = strpos( $line, $delim, $current );
  if( $next === false )
    return substr( $line, $current );
  else
  {
    return substr( $line, $current, $next - $current );
  }
}



?>